@@ -53,12 +53,49 @@ class BaseHandler(RequestHandler):
                       type(getattr(self, m, None)) == types.MethodType,
             self.__dir__())))
 
+    def process_request(self, request):
+        """
+        预处理请求中间件，对请求内容进行改写
+        :param request:
+        :return:
+        """
+        pass
+
+    def process_view(self, request, view_func, view_args, view_kwargs):
+        """
+        视图中间件，对视图进行处理
+        :param request:
+        :param view_func:
+        :param view_args:
+        :param view_kwargs:
+        :return:
+        """
+        pass
+
+    def process_exception(self, exception: Exception):
+        """
+        异常处理中间件
+        :param exception:
+        :return:
+        """
+        raise exception
+
+    def process_response(self, data):
+        """
+        处理响应数据的中间件
+        :param data:
+        :return:
+        """
+        if data is not None:
+            self.write(json.dumps(ResponseResult(data=data), ensure_ascii=False, cls=JSONEncoder))
+
     async def get(self):
         """
         重写父类get请求处理方法，直接调用post方法统一处理
         :return:
         """
         logging.info(f"Request-Id: {self.request.headers.get('Request-Id', '')}")
+        self.process_request(self.request)
         await self.request_handler()
 
     async def post(self):
@@ -69,6 +106,7 @@ class BaseHandler(RequestHandler):
         :return:
         """
         logging.info(f"Request-Id: {self.request.headers.get('Request-Id', '')}")
+        self.process_request(self.request)
         await self.request_handler()
 
     async def options(self):
@@ -147,15 +185,18 @@ class BaseHandler(RequestHandler):
                         params_list.append(parse_val(argument_value, parameter_type))
 
             # 判断是否为异步非阻塞方法，true 则直接调用
-            if inspect.iscoroutinefunction(handler_method):
-                data = await handler_method(*params_list)
-            else:
-                # 阻塞方法异步调用
-                data = await IOLoop.current().run_in_executor(None, handler_method, *params_list)
-            self.end_time = int(round(time.time() * 1000))
-            self.set_header("Api-Time", f"{self.end_time - self.start_time}ms")
-            if data is not None:
-                self.write(json.dumps(ResponseResult(data=data), ensure_ascii=False, cls=JSONEncoder))
+            try:
+                if inspect.iscoroutinefunction(handler_method):
+                    data = await handler_method(*params_list)
+                else:
+                    # 阻塞方法异步调用
+                    data = await IOLoop.current().run_in_executor(None, handler_method, *params_list)
+                self.end_time = int(round(time.time() * 1000))
+                self.set_header("Api-Time", f"{self.end_time - self.start_time}ms")
+                self.process_response(data)
+            except Exception as e:
+                self.process_exception(e)
+
         else:
             raise BusinessException(StatusCode.RESOURCE_NOT_FOUND)
 
@@ -171,7 +212,8 @@ class BaseHandler(RequestHandler):
             self.set_header("Access-Control-Allow-Origin", "*")
         self.set_header("Request-Id", self.request.headers.get("Request-Id", ""))
         self.set_header("Plugin-Running-Time", self.request.headers.get("Plugin-Running-Time", ""))
-        self.set_header("Access-Control-Allow-Headers", "x-requested-with,Authorization,Can-read-cache,Content-Type,User")
+        self.set_header("Access-Control-Allow-Headers",
+                        "x-requested-with,Authorization,Can-read-cache,Content-Type,User")
         self.set_header("Access-Control-Allow-Methods", "POST,GET,PUT,DELETE,OPTIONS")
         self.set_header("Access-Control-Expose-Headers", "Access-Token")
         self.set_header("Access-Control-Allow-Credentials", "true")
